@@ -212,7 +212,9 @@ gint main(gint argc, gchar **argv)
         goto EXIT;
     }
 
+#if !GLIB_CHECK_VERSION(2,35,1)
     g_type_init();
+#endif
 
     loader = osinfo_loader_new();
     osinfo_loader_process_default_path(loader, &error);
@@ -236,10 +238,10 @@ gint main(gint argc, gchar **argv)
                 g_printerr(_("Error parsing media: %s\n"), error->message);
 
                 ret = -3;
-                goto EXIT;
             } else {
                 print_bootable(FALSE);
             }
+            goto EXIT;
         } else {
             print_bootable(TRUE);
         }
